API d'inventaire des pièces du concessionnaire
Commencer
Comme décrit dans la section Partage de données , le DCP concerne entièrement les données. Une donnée importante est l’inventaire des pièces, accessoires et vêtements (PAA) du concessionnaire (raccourci à inventaire des pièces), utilisé dans de nombreux programmes commerciaux de BRP.
Ceux-ci incluent, sans s’y limiter :
- La gestion des stocks au détail est un programme de réapprovisionnement automatique.
- Trouver en concession est un système qui permet aux consommateurs de consulter un large inventaire de pièces individuelles pour le concessionnaire de leur choix.
Notez que le partage de l’inventaire des pièces du concessionnaire est désormais inclus dans le programme de certification des concessionnaires : le concessionnaire perd des points lorsqu’il ne partage pas son inventaire de pièces.
Un objectif est de permettre aux concessionnaires de partager leurs inventaires PAA directement depuis leur DMS, plutôt que de les téléverser manuellement depuis BOSSWeb.
L’API d’inventaire des pièces du concessionnaire fournit deux services :
- Un service consiste à recevoir l’inventaire du concessionnaire et à le mettre à jour dans le système BRP.
- Un service permet de rechercher un numéro de pièce dans l’inventaire du concessionnaire (Concessionnaire à Concessionnaire).
Par où commencer ? Lisez ceci d’abord !
Avant de commencer à travailler sur cette API, vous devez lire les sections suivantes si vous ne les avez pas déjà consultées :
- Informations techniques pour des informations techniques générales sur l’API et les environnements.
- Authentification et informations d’identification pour des détails sur l’authentification et les identifiants.
Inventaire des pièces du concessionnaire
Votre DMS utilise le service d’inventaire des pièces pour envoyer l’inventaire du concessionnaire à BRP. Les informations d’inventaire du concessionnaire doivent être mises à jour quotidiennement, service d’inventaire des pièces même si le concessionnaire est fermé.
Les données d’inventaire du concessionnaire doivent être envoyées en dehors des heures d’ouverture afin de garantir que les valeurs les plus récentes soient transmises.
Le concessionnaire doit consentir au partage des données avant que vous envoyiez son inventaire de pièces à BRP.
Votre DMS doit uniquement envoyer l’inventaire des pièces des concessionnaires BRP Powersports ayant consenti au partage des données.
Reportez-vous à la section Partage de données pour plus d’informations sur le partage des données.
Localisateur de pièces du concessionnaire
Le service de localisation de pièces est utilisé pour rechercher une pièce dans l’inventaire d’un autre concessionnaire. La recherche est limitée à une distance du concessionnaire demandeur, avec une valeur par défaut de 200 km et un maximum de 8 000 km.
Le service permet au concessionnaire de trouver une pièce chez un autre concessionnaire qui pourrait être disponible plus rapidement que de commander la pièce auprès de BRP, par exemple si la pièce est en rupture de stock.
Pour rechercher la disponibilité et l’emplacement des pièces dans l’inventaire de BRP, consultez l’API d'inventaire des pièces
Informations techniques
Caractéristiques
Type d'API | Type DSP | Version DCP | Complexité |
|---|---|---|---|
Obtenir des données de BRP | DMS | V3 - International | Faible |
Envoyer des données à BRP | CRM | V4 - Amérique du Nord | Un peu plus |
Transaction avec BRP | | | Un peu plus encore |
Authentification
L’API utilise Authentification de l’application.
Vous avez besoin d’un jeton d’accès valide avant d’appeler cette API, ou vous devez appeler l’API d'authentification d'application pour en obtenir un.
Le jeton d’accès est valide pendant 30 minutes ! (1799 secondes)
URL de base
Test | https://qa-cloud-api.brp.com/dcp/<v3 ou v4> |
|---|---|
Production | https://cloud-api.brp.com/dcp/<v3 ou v4> |
Ressource : Inventaire des pièces du concessionnaire
Cette ressource met à jour l’inventaire des pièces du concessionnaire dans le système BRP.
Représentation JSON
{
"dealer_no": "0000691756",
"inventory_date": "{{INVENTORY_DATE}}",
"parts_inventory": [
{
"product_code": "420430408",
"qty_on_hand": 15,
"qty_dealer_stocking": 10,
"qty_available": 7,
"qty_min_stocking_level": 2,
"qty_max_stocking_level": 12,
"qty_best_stocking_level": 8,
"last_physical_inventory_date": "2022-02-01"
},
{
"product_code": "705800048",
"qty_on_hand": 6,
"qty_dealer_stocking": 4,
"qty_available": 2,
"qty_min_stocking_level": 1,
"qty_max_stocking_level": 6,
"qty_best_stocking_level": 3,
"last_physical_inventory_date": "2022-03-01"
}
]
}
Propriétés
Propriété | Type | Définition | Notes |
|---|---|---|---|
dealer_no * | chaîne | Code identifiant de manière unique un concessionnaire. Doit contenir 10 caractères. Si moins de 10 caractères, ajouter '0' au début. | Longueur : 10 |
* Ces champs sont obligatoires.
Ressource : Localisateur de pièces du concessionnaire
Cette ressource est utilisée pour localiser une pièce dans l'inventaire du concessionnaire.
Les concessionnaires disposant de la pièce demandée dans la quantité requise sont renvoyés et triés par distance, du plus proche au plus éloigné.
Si le concessionnaire appelant le service de localisation de pièces concessionnaires possède la pièce demandée dans la quantité requise, le concessionnaire sera le premier renvoyé dans le tableau dealersavec une distance de 0.
Si la pièce n’est pas trouvée, une liste vide de concessionnaires est renvoyée.
Représentation JSON
{
"req_product_code": "204130096",
"req_qty": "5",
"dealers": [
{
"dealer_no": "0000700916",
"dealer_name": "PERFORMANCE NC - PRINCEVILLE",
"address": {
"street": "780 BL. BARIL OUEST (RTE 116)",
"city": "PRINCEVILLE",
"state": "QC",
"country": "CA",
"postal_code": "G6L 3W6"
},
"language": "FR",
"time_zone": "UTC-05000",
"phone_no": "819-505-0712",
"distance": 0
},
{
"dealer_no": "0000691731",
"dealer_name": "MERCIER MARINE LTEE",
"address": {
"street": "3670 BOUL. FRONTENAC OUEST",
"city": "THETFORD MINES",
"state": "QC",
"country": "CA",
"postal_code": "G6H 2B8"
},
"language": "FR",
"time_zone": "UTC-05000",
"phone_no": "418-423-5517",
"distance": 42.3
},
{
"dealer_no": "0000694650",
"dealer_name": "PERFORMANCE N.C. INC.",
"address": {
"street": "176 BOUL. INDUSTRIEL",
"city": "ST-GERMAIN DE GRANTHAM",
"state": "QC",
"country": "CA",
"postal_code": "J0C 1K0"
},
"language": "FR",
"time_zone": "UTC-05000",
"phone_no": "819-395-2464",
"distance": 84.2
}
]
}Propriétés
Propriété | Type | Définition | Notes |
|---|---|---|---|
req_product_code | string | Code produit (identique au numéro de pièce) demandé par le concessionnaire | Longueur max : 18 |
req_qty | integer | Quantité demandée par le concessionnaire | Format : 999999 |
dealers | Liste d'objets | Liste des concessionnaires ayant la pièce demandée en inventaire |
|
dealers.dealer_no | string
| Numéro du concessionnaire. Doit comporter 10 caractères. Si moins de 10 caractères, ajouter '0' au début. | Longueur : 10 |
dealers.dealer_name | string | Nom du concessionnaire | Longueur max : 80 |
dealers .address | Objet | Adresse du concessionnaire |
|
dealers.address. street | string | Adresse (1ère ligne) | Longueur max : 60 |
dealers.address .city | strin | Ville | Longueur max : 40 |
dealers.address .state | string | Code identifiant de manière unique une province/état dans un pays, au format ISO 3166-2 (2e partie) | Longueur max : 3 |
dealers.address .country | string | Code identifiant de manière unique un pays, au format ISO 3166-1 | Longueur max : 2 |
dealers.address .postal_code | string | Code postal du concessionnaire | Longueur max : 10 |
dealers.language | string | Langue de communication du concessionnaire au format ISO (ISO-639-1 + ISO 3166-1) | Format xx-XX |
dealers.time_zone | string | Fuseau horaire correspondant à la région du concessionnaire selon ISO 8601. | Format : UTC±HH:MM |
dealers.phone_no | string | Numéro de téléphone du concessionnaire | Longueur max : 16 |
dealers.distance | decimal
| Distance totale entre l’origine et le concessionnaire, selon l’unité demandée (km ou mi). Le calcul est effectué selon la distance routière si disponible, sinon à vol d’oiseau. | Format 99999.9 |
Limites et contraintes
Concessionnaires BRP Powersports et consentement au partage de données
Votre DMS doit seulement envoyer l’inventaire des pièces provenant des concessionnaires BRP Powersports qui ont consenti au partage des données.
L’inventaire des pièces envoyé doit contenir uniquement des pièces BRP.
Taille de la charge utile
L’API d’inventaire des pièces du concessionnaire fonctionne sur APIGee, qui a une taille maximale de charge utile de 10 Mo.
À titre de référence, la limite de 10 Mo représente un maximum de 30 000 pièces dans la charge utile si tous les champs optionnels sont envoyés.
Voir la section 413 Entité de requête trop volumineuse pour plus d’informations sur la gestion du code d’état 413.
👉 Pour éviter des problèmes avec la limite de taille de charge utile de 10 Mo, l’API d’inventaire des pièces du concessionnaire accepte un maximum de 30 000 pièces dans votre charge utile.
Si l’inventaire du concessionnaire contient plus de 30 000 pièces, vous devez envoyer autant de charges utiles de 30 000 pièces que nécessaire.
Valeur maximale du compteur
Toutes les quantités de charge utile de l’inventaire des pièces ont une valeur maximale de 999 999.
Certains concessionnaires utilisent une très grande valeur de quantity_on_hand dans leur inventaire pour les petites pièces, comme les rondelles et les vis, afin d’éviter de toutes les compter.
Pour toutes les valeurs de comptage supérieures à 999 999, vous devez arrondir la valeur à 999 999 dans la charge utile.
Localisateur de pièces du concessionnaire et quantité disponible
La ressource Localisateur de pièces du concessionnaire utilise la quantité en stock pour déterminer si un concessionnaire possède la pièce demandée dans son inventaire.
Une recherche plus précise utiliserait la quantité disponible , qui représente la quantité que le concessionnaire a disponible pour être libérée de l’inventaire. Elle est traditionnellement définie comme la quantité en stock moins les pièces réservées ou grevées.
Cependant, la quantité disponible est facultative dans l’inventaire des pièces du concessionnaire et n’est actuellement pas une source d’information fiable.
⛔ Numéro de pièce avec '-'
Au moment de la rédaction, le service Trouver une pièce (Localisateur de pièces) ne peut pas être utilisé avec un numéro de pièce contenant un « - ».
Le problème provient de l’API backend appelée par l’API d’inventaire des pièces du concessionnaire DCP. Il n’y a actuellement aucune date prévue pour une correction.
Par exemple, l’appel :
GET https://cloud-api.brp.com/dcp/v4/part/3602-072/dealer-inventory?req_qty=1&dealer_no=0000708172
Renvoie un statut 400.
{
"status": 400,
"errors": [
{
"code": "invalid_query",
"title": "Invalid query parameters were specified",
"meta": [
{
"type": "field",
"value": "3602-072",
"msg": "product code must be alpha numeric",
"path": "product_code",
"location": "query"
}
]
}
]
}Référence API
curl --location 'https://qa-cloud-api.brp.com/dcp/v3/parts/dealer-inventory' \
--header 'Dealer-Number: 0000691756' \
--header 'Content-Type: application/json' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' \
--data '{
"dealer_no": "0000691756",
"inventory_date": "{{INVENTORY_DATE}}",
"parts_inventory": [
{
"product_code": "779140",
"qty_on_hand": 773,
"qty_dealer_stocking": 947,
"qty_available": 831,
"qty_min_stocking_level": 780,{{INVENTORY_DATE}}
"qty_max_stocking_level": 145,
"qty_best_stocking_level": 156,
"last_physical_inventory_date": "2022-12-02"
}
]
}'curl --location 'https://qa-cloud-api.brp.com/dcp/v4/part/204130096/dealer-inventory?req_qty=1&dealer_no=0000700916&unit=mi&radius=23' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' \
Comment faire
Cette section fournit des informations sur la façon d’obtenir des résultats spécifiques avec l’API.
Trouver une pièce dans l’inventaire des concessionnaires
Recherchez un numéro de pièce avec 5 pièces disponibles dans l’inventaire des pièces des concessionnaires en utilisant le rayon par défaut de 200 km.
Dans cet exemple, le concessionnaire qui demande la pièce en a au moins 5 dans son inventaire.
Il y a également 2 autres concessionnaires ayant au moins 5 pièces disponibles dans leur inventaire.
curl --location 'https://cloud-api.brp.com/dcp/v4/part/204130096/dealer-inventory?req_qty=5&dealer_no=0000700916' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' Trouver une pièce chez les concessionnaires avoisinants
Rechercher un numéro de pièce avec 3 pièces disponibles dans l’inventaire des concessionnaires dans un rayon de 80 km.
Dans cet exemple, le concessionnaire qui demande la pièce en a au moins 3 dans son inventaire.
Il y a également un autre concessionnaire ayant au moins 3 pièces disponibles dans son inventaire.
curl --location 'https://cloud-api.brp.com/dcp/v4/part/204130096/dealer-inventory?req_qty=3&dealer_no=0000700916&unit=km&radius=80' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN'Pièce demandée introuvable
Recherchez un numéro de pièce avec 5 pièces disponibles dans l’inventaire des pièces des concessionnaires dans un rayon de 75 km. La liste des concessionnaires est vide si aucun concessionnaire n’a la pièce disponible dans la quantité demandée.
curl --location 'https://cloud-api.brp.com/dcp/v4/part/12345678/dealer-inventory?req_qty=5&dealer_no=0000700916&unit=km&radius=75' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' Gestion des erreurs
Cette section présente divers scénarios d'appels incorrects ou erronés, qui entraînent des messages d’erreur et des résultats incorrects.
Inventaire des pièces du concessionnaire
400 Mauvaise Requête
Le code d’état 400 est généralement rencontré durant le développement et l’intégration, et il ne devrait pas survenir lors d’opérations normales. La réponse renvoyée contient les informations nécessaires pour corriger le problème.
De nombreux problèmes peuvent provoquer un code d’état 400 ; les plus courants sont répertoriés dans le tableau ci-dessous.
Réponse | Résolution |
|---|---|
Retourné si le numéro de concessionnaire est invalide. {
"status": 400,
"id": "rrt-0570f...",
"title": "bad_request",
"meta": {
"service": "01",
"detail": "Le numéro de concessionnaire fourni n'existe pas ou est invalide."
}
} | Si le concessionnaire utilise votre DMS, il est possible qu’il ne soit plus un concessionnaire BRP. Vérifiez avec lui et désactivez les mises à jour d’inventaire des pièces. Assurez-vous que le numéro de concessionnaire comporte 10 caractères. Si vous enregistrez le numéro sans le '0' initial, ajoutez-le avant d’appeler l’API. L’erreur est aussi retournée si le concessionnaire n’est pas un concessionnaire BRP actif. |
Retourné si la date d’inventaire a un format invalide. {
"status": 400,
"id": "rrt-0570f8640a6...",
"title": "bad_request",
"meta": {
"service": "01",
"code": "échec de la validation de la requête",
"errors": {
"details": [
{
"message": "[Chemin '/inventory_date'] La chaîne \"25-11-2023T15:18:58Z\" est invalide selon les formats de date requis [yyyy-MM-dd'T'HH:mm:ssZ, yyyy-MM-dd'T'HH:mm:ss.[0-9]{1,12}Z]: []"
}
]
}
}
} | Modifiez le format de la chaîne de date pour correspondre au format du payload. |
Retourné si une quantité dépasse la limite. {
"status": 400,
"id": "rrt-0debaee1f7de5...",
"title": "bad_request",
"meta": {
"service": "01",
"code": "échec de la validation de la requête",
"errors": {
"details": [
{
"message": "[Chemin '/parts_inventory/0/qty_on_hand'] La valeur numérique dépasse le maximum autorisé (maximum : 999999, trouvé : 1000000): []"
}
]
}
}
} | Toutes les quantités du payload ont une valeur maximale de 999 999. Si votre DMS permet une valeur plus élevée et que le concessionnaire l’utilise, vous devez arrondir la valeur à 999 999 avant d’envoyer l’inventaire des pièces. |
La liste des pièces est vide. {
"status": 400,
"id": "rrt-0cdea36b8097f17...",
"title": "bad_request",
"meta": {
"service": "07",
"payload": {
"errors": "Le tableau 'parts_inventory' ne doit pas être vide."
}
}
} | Le payload envoyé contient une liste de pièces vide. Lors de l'application des filtres définis dans la Exigences Fonctionnelles , n’envoyez pas l’inventaire des pièces si la liste est vide. En théorie, cela ne devrait jamais arriver, car cela signifierait que toutes les pièces BRP ont une quantity_on_hand de 0. |
Retourné si le payload contient plus de 30 000 éléments. {
"status": "400",
"id": "rrt-06c1b7ac7365beb8f-d-ea-22696-1347602-1",
"title": "bad_request",
"meta": {
"service": "01",
"detail": "échec de la validation de la requête",
"payload": {
"details": [
{
"message": "[Chemin '/parts_inventory'] Le tableau est trop long : il doit contenir au maximum 30000 éléments, mais en contient 40000 : []"
}
]
}
}
} | Divisez l’inventaire des pièces afin d’envoyer plusieurs payloads contenant au maximum 30 000 éléments chacun. |
Voici un exemple d'appel au service d'inventaire des pièces du concessionnaire renvoyant un code d’état 400 Bad Request.
curl --location 'https://qa-cloud-api.brp.com/dcp/v3/parts/dealer-inventory' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' \
--data '{
"dealer_no": "1234567890",
"inventory_date": "2022-11-23T15:18:58Z",
"parts_inventory": [
{
"product_code": "779140",
"qty_on_hand": 15,
"qty_dealer_stocking": 10,
"qty_available": 7,
"qty_min_stocking_level": 2,
"qty_max_stocking_level": 12,
"qty_best_stocking_level": 8,
"last_physical_inventory_date": "2022-02-01"
}
]
}'413 Entité de requête trop volumineuse
Le code d’état 413 Request Entity Too Large est renvoyé lorsque la charge utile dépasse la limite APIGee de 10 Mo.
Notez que le code d’état 413 peut être reçu même si la charge utile que vous envoyez fait moins de 10 Mo. La charge utile est traitée et convertie avant d’être appelée par une API interne BRP, et cette API interne peut renvoyer un code d’état 413.
Pour corriger le problème :
- Envoyez uniquement les parties qui ont une valeur non nulle.
- Ne les envoyez pas si le concessionnaire n’utilise pas les propriétés optionnelles, comme qty_min_stocking_level.
401 Non autorisé
Le code d’erreur 401 Non autorisé est renvoyé lorsque vous tentez d’appeler l’API Dealer Parts Inventory avec un access_token expiré.
Vous devez obtenir un nouveau access_token avec un appel à l’API d'authentification d'application.
Localisateur de pièces du concessionnaire
400 Mauvaise requête
Le code d’état 400 est généralement rencontré lors du développement et de l’intégration, et il ne devrait pas être reçu pendant les opérations normales. La réponse renvoyée contient les informations nécessaires pour corriger le problème.
De nombreux problèmes peuvent entraîner un code d’état 400 ; les plus courants figurent dans le tableau ci‑dessous.
Réponse | Résolution |
|---|---|
Le code produit est manquant {
"status": 400,
"id": "rrt-0570f8640a6f6e...",
"title": "bad_request",
"meta": {
"service": "01",
"code": "request validation failed",
"errors": {
"details": [
{
"message": "Query parameter 'sales_org' is required on path '/part/{part_number}' but not found in request."
},
{
"message": "Query parameter 'currency' is required on path '/part/{part_number}' but not found in request."
},
{ | Le numéro de pièce (code produit) est manquant dans la requête. |
Numéro de concessionnaire invalide {
"status": 400,
"id": "rrt-0b8f470f8a6f5fd93-d-ea-19152-79657993-1.1",
"title": "not_found",
"meta": [
{
"service": "07",
"payload": {
"errors": {
"error_id": "4042",
"error_message": "The dealer_no is invalid"
}
}
}
]
} | Si le concessionnaire utilise votre DMS, cela peut être parce qu’il n’est plus un concessionnaire BRP. Vérifiez avec lui et désactivez les mises à jour de l’inventaire des pièces. Assurez-vous que le numéro de concessionnaire comporte 10 caractères. Si vous enregistrez le numéro de concessionnaire sans les zéros initiaux, ajoutez-les avant d’appeler l’API. |
Code produit (numéro de pièce) invalide {
"status": 404,
"id": "rrt-0b8f470f8a6f...",
"title": "not_found",
"meta": [
{
"service": "07",
"payload": {
"errors": {
"error_id": "4043",
ln "error_message": "The product_no is invalid"
}
}
}
]
} | Toutes les quantités dans la charge utile ont une valeur maximale de 999,999. Si votre DMS permet une valeur plus élevée et que le concessionnaire l’utilise, vous devez arrondir la valeur à 999,999 avant d’envoyer l’inventaire des pièces. |
401 Non autorisé
Le code d’erreur 401 Non autorisé est renvoyé lorsque vous tentez d’appeler l’API avec un access_token expiré.
Vous devez obtenir un nouveau access_token avec un appel à l’API d'authentification d'application.
Le code d’erreur 401 Unauthorized est également renvoyé si vous n’avez pas demandé l’accès à l’API en créant un ticket dans le Jira du DCP.
Lorsque vous êtes prêt à commencer à travailler sur une API, vous devez créer un ticket de certification dans Jira, comme décrit dans la section Activités de certification avec Jira.
Si vous avez déjà commencé à travailler sur une API et perdu l’accès, créez un ticket de support comme décrit dans la section Ouvrir un ticket de support.
404 Introuvable
Le code d’état 404 Not Found est renvoyé uniquement par la version V3 si le numéro de pièce est invalide.
Dans V4, une liste de revendeurs vide est renvoyée lorsque le numéro de pièce est introuvable.
Le code d’état 404 Not Found est renvoyé lorsque la pièce est introuvable.
curl --location 'https://qa-cloud-api.brp.com/dcp/v3/part/123456789/dealer-inventory?req_qty=2&dealer_no=0000691737&unit=mi&radius=170.2' \
--header 'Authorization: Bearer YOUR_ACCESS_TOKEN' Correction
Le concessionnaire a peut-être saisi un numéro de pièce invalide.
Exigences DSP
Exigences fonctionnelles
ID | Type | Exigence |
|---|---|---|
1 | Obligatoire | Le stock de pièces du concessionnaire doit être envoyé automatiquement chaque jour, même si le concessionnaire est fermé, en dehors des heures d'ouverture du concessionnaire, pour tous les concessionnaires ayant consenti au partage des données. ❗ Le stock de pièces du concessionnaire doit être envoyé automatiquement sans action manuelle du concessionnaire ❗ |
2 | Obligatoire | Seules les pièces BRP doivent être envoyées au stock du concessionnaire. Les pièces provenant d'autres OEM et les pièces définies par le concessionnaire ne doivent pas être envoyées. |
4 | Obligatoire | Pour toutes les valeurs supérieures à 999 999, arrondir la valeur à 999 999. |
5 | Obligatoire | Votre DMS doit envoyer un maximum de 30 000 pièces dans une charge utile. S'il y a plus de 30 000 pièces dans le stock du concessionnaire, vous devez envoyer autant de charges utiles de 30 000 pièces que nécessaire. |
6 | Obligatoire | Seul le stock de pièces des concessionnaires BRP Powersports doit être envoyé lorsque le concessionnaire a consenti au partage des données. |
7 | Obligatoire | Si le concessionnaire retire son consentement au partage des données et cesse d'être un concessionnaire BRP, la transmission des données de stock de pièces doit être désactivée. |
8 | Obligatoire | L’inventaire des pièces du concessionnaire doit être appelé afin d’envoyer l’intégralité du stock de pièces du concessionnaire, PAS une pièce à la fois. |
Activités de certification
Cette section présente toutes les activités de certification et les validations qui doivent être effectuées pour certifier l'API.
Assurance qualité - POST
Les tests répertoriés dans le tableau ci-dessous doivent être réalisés avec succès dans l'environnement de test avant que vous puissiez commencer la phase pilote concessionnaire.
ID | Test | Résultat attendu |
|---|---|---|
1 | Envoyer l’inventaire pour une pièce | L’inventaire a été reçu et aucune erreur n’apparaît dans le journal de l’API. |
2 | Envoyer un inventaire complet du concessionnaire | L’inventaire a été reçu et aucune erreur n’apparaît dans le journal de l’API. L’équipe DCP vérifie que l’inventaire des pièces ne contient pas de pièces non BRP. |
3 | Tout l’inventaire reçu | L’inventaire des pièces est reçu pour tous les concessionnaires ayant donné leur consentement au partage des données. |
4 | Inventaire mis à jour | Vérifier que l’inventaire du concessionnaire est mis à jour, c’est‑à‑dire que la quantité de certaines pièces change au fil du temps. |
5 | Envoyer l’inventaire de données fractionnées | Vérifier que plusieurs charges utiles sont envoyées si l’inventaire du concessionnaire dépasse 30 000 pièces. 👉 Si l’inventaire du concessionnaire utilisé pour les tests contient moins de 30 000 pièces, vous devez modifier la limite dans votre DMS pour envoyer au moins 2 charges utiles. |
6 | Mises à jour automatisées | Vérifier que l’inventaire est envoyé automatiquement chaque jour pendant 5 jours consécutifs. |
Assurance qualité - GET
Les tests énumérés dans le tableau ci-dessous doivent être effectués dans l’environnement de test avant que vous puissiez commencer la phase pilote du concessionnaire.
ID | Test | Résultat attendu |
|---|---|---|
1 | Rechercher la pièce 517308658 sans rayon et avec une quantité de 1 | Une liste de concessionnaires devrait être trouvée. |
2 | Rechercher la pièce 517308658 avec un rayon de 100 mi ou km et une quantité de 10 | Une liste de concessionnaires devrait être trouvée. |
3 | Rechercher la pièce 517308658 avec un rayon de 15000 mi ou km et une quantité de 3 | Une liste de concessionnaires devrait être trouvée. |
4 | Rechercher la pièce 219400698 avec un rayon de 75 mi ou km et une quantité de 5 | La liste des concessionnaires devrait être vide. |
Les numéros de pièce suivants sont disponibles pour les tests :
- 715005683
- 517308658
- 219906024
- 706203893
- 224081201
- 9779126
- S40100RCA000
Pilote Revendeur
Le tableau ci-dessous présente les paramètres du pilote revendeur et leurs validations correspondantes.
Paramètre | Valeur |
|---|---|
Environnement | Production |
Nombre de concessionnaires | 1 à 3 |
Durée | 1 semaine |
Validation 1 | L'équipe DCP vérifie que l'inventaire des pièces des concessionnaires est reçu quotidiennement. |
Validation 2 | L'équipe DCP vérifie que l'inventaire des pièces des concessionnaires ne contient pas de pièces non-BRP. |
Validation 3 | Pour chaque concessionnaire du projet pilote, vous exportez l'inventaire du concessionnaire vers un fichier Excel, CSV ou JSON pendant 5 jours (les jours n'ont pas besoin d'être consécutifs). L'équipe DCP valide que l'inventaire reçu correspond à l'inventaire dans les fichiers d’export. |
Validation 4 | L'équipe DCP vérifie qu'il n'y a aucune erreur dans le journal de l'API. |
Validation 5 | Envoyez des captures d'écran des résultats de recherche du localisateur de pièces. Une pièce recherchée pour chaque ligne de produits prise en charge par le concessionnaire, pour chaque concessionnaire. |
Postman
Cette section décrit ce qui est disponible dans Postman pour explorer l’API.
Environnements
Un environnement Postman est disponible pour essayer l’API d’inventaire des pièces des concessionnaires. Cet environnement Postman contient des variables utilisées par les requêtes et est configuré pour se connecter à l’environnement de test.
Collections
La collection DMS - Inventaire des pièces des concessionnaires comprend des exemples d’appels API pour mettre à jour l’inventaire des pièces d’un concessionnaire et rechercher une pièce dans celui-ci.